@@ -1,6 +1,8 @@
 import logging
 
 from .scoresaber import ScoreSaber
+from .scoresaber_api import ScoreSaberAPI
+from .scoresaber_provider import ScoreSaberProvider
 from .errors import *
 from .models import *
 
